FastFieldCodecType

Enum FastFieldCodecType 

#[repr(u8)]
pub enum FastFieldCodecType { Bitpacked = 1, Linear = 2, BlockwiseLinear = 3, }
Available codecs to use to encode the u64 (via MonotonicallyMappableToU64) converted data.

Variants



Bitpacked = 1

Bitpack all values in the value range. The number of bits is defined by the amplitude column.max_value() - column.min_value()



Linear = 2

Linear interpolation puts a line between the first and last value and then bitpacks the values by the offset from the line. The number of bits is defined by the max deviation from the line.



BlockwiseLinear = 3

Same as FastFieldCodecType::Linear, but encodes in blocks of 512 elements.